/*  HP LaserJet Print Preparation Utility
**  Conoco Inc.,   Lee S. Fields\n
**
**    Function:  Removes trailing carriage returns/linefeeds and converts
**               IBM Graphics characters to HP LaserJet approximations.
**
**    Input:     Uses stdin for input, files may be redirected.
**
**    Output:    Uses stdout for output, files may be redirected.
**
**    Example:   To route a file to LPT1, use the format:
**
**             HPLJPREP <example.prn >LPT1
*/

#include <stdio.h>
#include <conio.h>

#define MAX  50
#define LF   0x0a
#define TRUE 1
#define FALSE 0
#define FF    0x0c

main(argc,argv)
int argc;
char **argv;
{
   int c, outc;
   int stkflag;

   vanity();

   if(argc > 1) 
   {
       instruct();
       exit(0);
   }

   fprintf(stderr,"\nNow processing . . .\n");

   while( (c=getchar()) != EOF)
   {
       if( c == LF)   /* push linefeeds */
       {
           push(c);
           stkflag=TRUE;
       }
       else if( c == FF)    /* clear stack and pass formfeeds */
       {
           while((outc=pop()) != NULL)
           ;
           stkflag=FALSE;
           putchar(c);
       }
       else if(stkflag)    /*  clear stack then pass char */
       {
           while((outc=pop()) != NULL)
               putchar(outc);
           stkflag=FALSE;
           c=prtrns(c);
           putchar(c);
       }
       else       /* pass char */
       {
           c=prtrns(c);
           putchar(c);
       }
   } /* end while */

   putchar(FF); /* clear out printer */

} /* end main */

/*
**  P R I N T E R   T R A N S L A T E
**
**  Copyright 1986 Bob Pritchett
**
**  Created: 02/22/86   Last Updated: 02/22/86
**
*/

prtrns(c)
int c;
 {
  if ( ( c > 179 && c < 218 ) && ((c != 196) && (c != 205) && (c != 186)) )
     return(42);
  else if ( c == 196 )
     return(45);
  else if ( c == 205 )
     return(61);
  else if ( c == 179 || c == 186 )
     return(124);
  else
     return(c);
 }

vanity()
{
   fprintf(stderr,"\nHP LaserJet Print Preparation Utility");
   fprintf(stderr,"\nConoco Inc.,   Lee S. Fields\n");
}

instruct()
{
   fprintf(stderr,"\n\nFunction:\tRemoves trailing carriage returns/linefeeds and converts");
   fprintf(stderr,"\n\t\tIBM Graphics characters to HP LaserJet approximations.");
   fprintf(stderr,"\n\nInput:\t\tUses stdin for input, files may be redirected.");
   fprintf(stderr,"\n\nOutput:\t\tUses stdout for output, files may be redirected.");
   fprintf(stderr,"\n\nExample:\tTo route a file to LPT1, use the format:");
   fprintf(stderr,"\n\n\t\tHPLJPREP <example.prn >LPT1\n\n\n");
}


char stack[MAX];
int top=0;

push(x)
int x;
{
   if(top<MAX)
       return(stack[++top]=x);
}

pop()
{
   if(top>0)
       return(stack[top--]);
   else
       return(NULL);
}
